@@ -25,9 +25,13 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QDir>
-#include <QDebug>
+#include <QLoggingCategory>
 #include <QPluginLoader>
 
+Q_DECLARE_LOGGING_CATEGORY(MIGRATOR)
+// logging category for this framework, default: log stuff >= warning
+Q_LOGGING_CATEGORY(MIGRATOR, "kf5.kcoreaddons.kdelibs4configmigrator", QtWarningMsg)
+
 class Kdelibs4ConfigMigrator::Private
 {
 public:
@@ -70,9 +74,11 @@ bool Kdelibs4ConfigMigrator::migrate()
         return false;
     }
 
+    bool didSomething = false;
+
     Q_FOREACH (const QString &configFileName, d->configFiles) {
         const QString newConfigLocation
-            = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation)
+            = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)
               + QLatin1Char('/') + configFileName;
 
         if (QFile(newConfigLocation).exists()) {
@@ -84,8 +90,10 @@ bool Kdelibs4ConfigMigrator::migrate()
 
         const QString oldConfigFile(migration.locateLocal("config", configFileName));
         if (!oldConfigFile.isEmpty()) {
-            QFile(oldConfigFile).copy(newConfigLocation);
-            qDebug()<<"old config "<<oldConfigFile << " was migrated to "<<newConfigLocation;
+            if (QFile(oldConfigFile).copy(newConfigLocation)) {
+                didSomething = true;
+                qCDebug(MIGRATOR) << "config file" << oldConfigFile << "was migrated to" << newConfigLocation;
+            }
         }
     }
 
@@ -104,17 +112,22 @@ bool Kdelibs4ConfigMigrator::migrate()
 
             const QString oldConfigFile(migration.locateLocal("data", d->appName + QLatin1Char('/') + uiFileName));
             if (!oldConfigFile.isEmpty()) {
-                QFile(oldConfigFile).copy(newConfigLocation);
-                qDebug()<<"old config "<<oldConfigFile << " was migrated to "<<newConfigLocation;
+                if (QFile(oldConfigFile).copy(newConfigLocation)) {
+                    didSomething = true;
+                    qCDebug(MIGRATOR) << "ui file" << oldConfigFile << "was migrated to" << newConfigLocation;
+                }
             }
         }
     }
 
     // Trigger KSharedConfig::openConfig()->reparseConfiguration() via the framework integration plugin
-    QPluginLoader lib(QStringLiteral("kf5/FrameworkIntegrationPlugin"));
-    QObject *rootObj = lib.instance();
-    if (rootObj) {
-        QMetaObject::invokeMethod(rootObj, "reparseConfiguration");
+    if (didSomething) {
+        QPluginLoader lib(QStringLiteral("kf5/FrameworkIntegrationPlugin"));
+        QObject *rootObj = lib.instance();
+        if (rootObj) {
+            QMetaObject::invokeMethod(rootObj, "reparseConfiguration");
+        }
     }
+
     return true;
 }
